@@ -50,7 +50,6 @@ CDDBConfigWidget::CDDBConfigWidget(QWidget * parent)
   layout->setContentsMargins(0, 0, 0, 0);
   layout->addWidget(groupBox);
 
-  connect(needsAuthenticationBox,&QAbstractButton::toggled,this, &CDDBConfigWidget::needAuthenticationChanged);
   connect(kcfg_FreedbLookupTransport,QOverload<int>::of(&QComboBox::activated),this, &CDDBConfigWidget::protocolChanged);
   connect(kcfg_FreedbLookupEnabled,&QAbstractButton::toggled,freedbServerBox,&QWidget::setEnabled);
   connect(mirrorListButton,&QAbstractButton::clicked,this, &CDDBConfigWidget::showMirrorList);
@@ -100,11 +99,6 @@ void CDDBConfigWidget::protocolChanged()
       kcfg_port->setValue(8880);
 }
 
-void CDDBConfigWidget::needAuthenticationChanged(bool needsAuth)
-{
-    kcfg_smtpUsername->setEnabled(needsAuth);
-    if (!needsAuth)
-      kcfg_smtpUsername->clear();
-}
+#include "moc_cddbconfigwidget.cpp"
 
 // vim:tabstop=2:shiftwidth=2:expandtab:cinoptions=(s,U1,m1
