@@ -2,6 +2,6 @@
 #define KCDDBI18N_H
 
 #define TRANSLATION_DOMAIN "libkcddb"
-#include <KI18n/KLocalizedString>
+#include <KLocalizedString>
 
 #endif // KCDDBI18N_H
